from polyglot import license
from django.conf import settings


class LicenseError(Exception):
    license: dict[str, str]

    def __init__(self, license: dict[str, str]):
        self.license = license
        super().__init__(
            f"\n\nThe provided license is empty or invalid.\n Your license is: {self.license}"
        )


class DjangoLicenseManager(license.LicenseManager):
    def get_license(self) -> license.License:
        deepl_license: dict[str, str] = settings.DEEPL_LICENSE
        try:
            key: str = deepl_license["key"]
            version: license.LicenseVersion = license.LicenseVersion(
                deepl_license["version"]
            )
            return license.License(key=key, version=version)
        except:
            raise LicenseError(license=deepl_license)

    def set_license(self) -> None:
        pass



from polyglot import arguments
from . import license


class DjangoArgumentsCollector(arguments.ArgumentsCollector):

    action: str
    source_file: str
    target_lang: str
    output_directory: str
    source_lang: str

    def __init__(
        self,
        action: str,
        source_file: str = "",
        target_lang: str = "",
        output_directory: str = "",
        source_lang: str = "",
    ):
        self.action = action
        self.source_file = source_file
        self.target_lang = target_lang
        self.output_directory = output_directory
        self.source_lang = source_lang
        super().__init__()

    def _collect_arguments(self) -> None:
        self.arguments = arguments.Arguments(
            action=self.action,
            source_file=self.source_file,
            target_lang=self.target_lang,
            output_directory=self.output_directory,
            source_lang=self.source_lang,
            license_manager=license.DjangoLicenseManager(),
        )

    def _validate_arguments(self) -> None:
        pass



#!/usr/bin/env python3
import pathlib
from setuptools import find_packages, setup
import djangoPolyglot

HERE = pathlib.Path(__file__).parent
README = (HERE / "README.md").read_text()

setup(
    name="django-polyglot-translator",
    version=djangoPolyglot.__version__,
    description="Polyglot integration for Django Web Framework",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/riccardoFasan/django-polyglot",
    project_urls={
        "BugTracker": "https://github.com/riccardoFasan/django-polyglot/issues",
        "Homepage": "https://github.com/riccardoFasan/django-polyglot",
    },
    author="Riccardo Fasan",
    author_email="fasanriccardo21@gmail.com",
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8",
    packages=find_packages(exclude=("tests",)),
    include_package_data=True,
    install_requires=["Django>3.1.7" "polyglot-translator>=2.0.4"],
    setup_requires=["Django>3.1.7" "polyglot-translator>=2.0.4"],
)
